==> haskell-basic-prelude-0.7.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-KzQQJ0hL0Aj7jDklYPSle
key:                  basic-prelude-0.7.0-KzQQJ0hL0Aj7jDklYPSle
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  038a7645add3a3c9a5c18fb9d28291b7
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-8.10.3/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/basic-prelude-0.7.0
hs-libraries:         HSbasic-prelude-0.7.0-KzQQJ0hL0Aj7jDklYPSle
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    filepath-1.4.2.1 hashable-1.3.0.0-AuOWFkmW3BKQo2eaHHrrX
    text-1.2.4.1 transformers-0.5.6.2
    unordered-containers-0.2.13.0-23W4q6NjyfvEwgc8XDyWoD
    vector-0.12.1.2-2wQfnsplnY91earGv9FMCk

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basic-prelude-0.7.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-2p90HTqnBm7CijE5nBVKxs
key:                  basic-prelude-0.7.0-2p90HTqnBm7CijE5nBVKxs
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  89027b2bc55fd0a44aef694b3fc08aca
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-8.10.3/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/basic-prelude-0.7.0
hs-libraries:         HSbasic-prelude-0.7.0-2p90HTqnBm7CijE5nBVKxs
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    filepath-1.4.2.1 hashable-1.3.0.0-C4QpLHBwsCbBQudtxc3BPD
    text-1.2.4.1 transformers-0.5.6.2
    unordered-containers-0.2.13.0-3Ieg6EkO4CaEKR70vK4Wn9
    vector-0.12.2.0-8xKHNm2aOPS1mBXzhfDbwi

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
